package com.aucma.base.service;

import java.util.List;
import com.aucma.base.domain.BaseMonitorWorkUnit;

/**
 * 统计计量信息Service接口
 * 
 * @author Yinq
 * @date 2023-10-12
 */
public interface IBaseMonitorWorkUnitService 
{
    /**
     * 查询统计计量信息
     * 
     * @param objId 统计计量信息主键
     * @return 统计计量信息
     */
    public BaseMonitorWorkUnit selectBaseMonitorWorkUnitByObjId(Long objId);

    /**
     * 查询统计计量信息列表
     * 
     * @param baseMonitorWorkUnit 统计计量信息
     * @return 统计计量信息集合
     */
    public List<BaseMonitorWorkUnit> selectBaseMonitorWorkUnitList(BaseMonitorWorkUnit baseMonitorWorkUnit);

    /**
     * 新增统计计量信息
     * 
     * @param baseMonitorWorkUnit 统计计量信息
     * @return 结果
     */
    public int insertBaseMonitorWorkUnit(BaseMonitorWorkUnit baseMonitorWorkUnit);

    /**
     * 修改统计计量信息
     * 
     * @param baseMonitorWorkUnit 统计计量信息
     * @return 结果
     */
    public int updateBaseMonitorWorkUnit(BaseMonitorWorkUnit baseMonitorWorkUnit);

    /**
     * 批量删除统计计量信息
     * 
     * @param objIds 需要删除的统计计量信息主键集合
     * @return 结果
     */
    public int deleteBaseMonitorWorkUnitByObjIds(Long[] objIds);

    /**
     * 删除统计计量信息信息
     * 
     * @param objId 统计计量信息主键
     * @return 结果
     */
    public int deleteBaseMonitorWorkUnitByObjId(Long objId);
}
